#[repr(C)]pub struct utsname {
pub sysname: [c_char; 65],
pub nodename: [c_char; 65],
pub release: [c_char; 65],
pub version: [c_char; 65],
pub machine: [c_char; 65],
pub domainname: [c_char; 65],
}Expand description
Fields
sysname: [c_char; 65]Name of this implementation of the operating system.
nodename: [c_char; 65]Name of this node within the communications network to which this node is attached, if any.
release: [c_char; 65]Current release level of this implementation.
version: [c_char; 65]Current version level of this release.
machine: [c_char; 65]Name of the hardware type on which this system is running.
domainname: [c_char; 65]Non-POSIX.